# *****************************************************************
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2018, 2019. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# *****************************************************************

from __future__ import print_function
import os

# Load the data
import argparse
from sklearn.datasets import load_svmlight_file
from sklearn.model_selection import train_test_split
import numpy as np
from snap_ml_mpi.Utils import dump_to_snap_format


defaultPath = os.getcwd() 
CLI=argparse.ArgumentParser()
CLI.add_argument(
   "--data_path",
   type=str,
   default=defaultPath
)

args = CLI.parse_args()

print("Loading EPSILON dataset...")
X,y = load_svmlight_file(args.data_path + "/data/epsilon_normalized")
# Load the data

print('Splitting data...')
# Make the train-test split
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.25, random_state=42)

# Convert to numpy ararys
print('Converting to dense format...')
X_train = np.array(X_train.todense())
X_test  = np.array(X_test.todense())

print('Saving data in sklearn format...')
# # Save to libsvm files (index must start from 1)
np.save(args.data_path + "/data/epsilon.X_train", X_train)
np.save(args.data_path + "/data/epsilon.X_test",  X_test)
np.save(args.data_path + "/data/epsilon.y_train", y_train)
np.save(args.data_path + "/data/epsilon.y_test", y_test)

print('Saving data in distributed snap.ml format...')
# # Save to dense snap format
dump_to_snap_format(X_train, y_train, args.data_path + '/data/epsilon.train.snap')
dump_to_snap_format(X_test, y_test, args.data_path + '/data/epsilon.test.snap')
